@@ -1,14 +1,22 @@
+#######################################################
+# Author: Devin Francom, Los Alamos National Laboratory
+# Protected under GPL-3 license
+# Los Alamos Computer Code release C19031
+# github.com/lanl/BASS
+#######################################################
+
 ########################################################################
 ## make basis functions
 ########################################################################
 
 ## makes negative values 0
-pos<-function(vec){ 
-  replace(vec,vec<0,0)
+pos<-function(vec){
+  #replace(vec,vec<0,0)
+  (abs(vec)+vec)/2
 }
 
 ## largest value of basis function, assuming x's in [0,1], used for scaling
-const<-function(signs,knots,degree){ 
+const<-function(signs,knots,degree){
   cc<-prod(((signs+1)/2 - signs*knots))^degree
   if(cc==0)
     return(1)
@@ -16,7 +24,7 @@ const<-function(signs,knots,degree){
 } # since a product, can find for functional & categorical pieces separately, take product
 
 ## make basis function (from continuous variables)
-makeBasis<-function(signs,vars,knots,datat,degree){ 
+makeBasis<-function(signs,vars,knots,datat,degree){
   cc<-const(signs,knots,degree)
   temp1<-pos(signs*(datat[vars,,drop=F]-knots))^degree # this only works for t(data)...
   if(length(vars)==1){
@@ -37,4 +45,4 @@ makeBasisCat<-function(vars,sub,data){
     temp<-temp*as.numeric(data[,vars[ii]] %in% sub[[ii]])
   }
   return(temp)
-}
\ No newline at end of file
+}
